GtkWidget* create_hotlist_popup();

void add_to_hotlist(char* nick);
void remove_from_hotlist(char* nick);
void cmd_hotlist_ack(char* data);
void cmd_user_sign_on(char *data);
void cmd_user_sign_off(char *data);

void cmd_hotlist_error(char* data);

int is_user_in_hotlist(char* user);
void hotlist_search(search_pattern_t* search);
void hotlist_update_user();
void hotlist_update_stats();
void hotlist_remove_user_files(user_t* userinfo);
